@@ -1,6 +1,6 @@
 package App::ccdiff;
 
-our $VERSION = "0.23";
+our $VERSION = "0.24";
 
 use strict;
 use warnings
@@ -204,6 +204,14 @@ If a chunk describes a change, and the number of lines in the original block
 has less or more lines than the new block and that difference exceeds this
 threshold, C<ccdiff> will fall-back to vertical diff.
 
+=item --heuristics=n -h n
+
+Defines the percentage of character-changes a change block may differ before
+the fall-back of horizontal diff to vertical diff.
+
+This percentage is calculated as C<(characters removed + characters added) /
+(2 * characters unchanged))>. 
+
 =item --ignore-case -i
 
 Ignore case on comparison.
@@ -418,6 +426,14 @@ if file~ exists.
 Defines the number of lines a change block may differ before the fall-back of
 horizontal diff to vertical diff.
 
+=item heuristics (-h)
+
+ heuristics : 40
+
+Defines the percentage of character-changes a change block may differ before
+the fall-back of horizontal diff to vertical diff. The default is undefined,
+meaning no fallback based on heuristics.
+
 =back
 
 =head1 Git integration
